@@ -98,7 +98,7 @@ class PyGitlab(object):
             return AuthInfo(auth=HTTPBasicAuth('oauth2', self.pygitlab.oauth_token))
         if self.pygitlab.job_token:
             return AuthInfo(auth=HTTPBasicAuth('gitlab-ci-token', self.pygitlab.job_token))
-        if self.pygitlab.http_username:
+        if self.pygitlab.http_username and self.pygitlab.http_password:
             return AuthInfo(auth=HTTPBasicAuth(self.pygitlab.http_username, self.pygitlab.http_password))
         raise ValueError('No auth info')
 
