@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -481,7 +481,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
             # From https://docs.gitlab.com/ee/api/projects.html#edit-project
             'default_branch': {
                 'type': 'string',
-                'description': '`master` by default',
+                'description': 'The default branch name',
             },
             'autoclose_referenced_issues': {
                 'type': 'boolean',
@@ -564,12 +564,12 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                              '      branches: # if you omit this parameter, all branches are mirrored\n'
                              "        - from: '/wip-.*/'\n"
                              "          to: '' # This will skip those branches\n"
-                             '        - from: master\n'
-                             '          # to: master # implicitly equal to source branch\n'
+                             '        - from: main\n'
+                             '          # to: main # implicitly equal to source branch\n'
                              # '          # skip_ci: false # inherited by default \n'
                              # '          merge_request: true  '
                              # '# Will create a temporary branch and create '
-                             # 'a MR targeting master (the `to` parameter)\n'
+                             # 'a MR targeting main (the `to` parameter)\n'
                              # '          merge_request_from_fork: myself/myproject # will fork if needed\n'
                              '        # Using regexps\n'
                              "        - from: '/(.*)/'\n"
@@ -629,7 +629,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                     },
                 },
                 '_example': ('\n'
-                             '    master:\n'
+                             '    main:\n'
                              '      merge_access_level: maintainer # one of noone, developer, maintainer\n'
                              '      push_access_level: noone\n'
                              '    develop:\n'
@@ -669,7 +669,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 },
                 'uniqueItems': True,
                 '_example': ('\n'
-                             '    - master\n'
+                             '    - main\n'
                              '    - develop'),
             },
             'rename_branches': {
@@ -818,7 +818,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                              '    enabled: true\n'
                              '    cadence: 7d # 1d, 7d, 14d, 1month, 3month\n'
                              '    keep_n: 10 # 1, 5, 10, 25, 50, 100\n'
-                             "    name_regex_keep: '.*master|.*release|release-.*|master-.*'\n"
+                             "    name_regex_keep: '.*main|.*release|release-.*|main-.*'\n"
                              '    older_than: 90d\n'
                              "    name_regex_delete: '.*'\n"),
             },
@@ -1048,7 +1048,7 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 'uniqueItems': True,
                 '_example': ('\n'
                              '    - description: Build packages\n'
-                             '      ref: master\n'
+                             '      ref: main\n'
                              "      cron: '0 1 * * 5'\n"
                              '      # cron_timezone: UTC\n'
                              '      # active: true\n'
@@ -1075,6 +1075,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                 'items': {
                     'type': 'object',
                     'properties': {
+                        'enabled': {
+                            'type': 'boolean',
+                        },
                         'from': {
                             'oneOf': [
                                 {
@@ -1156,6 +1159,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                             'type': 'object',
                             'description': 'Raw source',
                             'properties': {
+                                'enabled': {
+                                    'type': 'boolean',
+                                },
                                 'raw': {
                                     'type': 'object',
                                     'properties': {
@@ -1200,6 +1206,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                             'type': 'object',
                             'description': 'Github source',
                             'properties': {
+                                'enabled': {
+                                    'type': 'boolean',
+                                },
                                 'github': {
                                     'type': 'object',
                                     'properties': {
@@ -1244,6 +1253,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                             'type': 'object',
                             'description': 'Helm source',
                             'properties': {
+                                'enabled': {
+                                    'type': 'boolean',
+                                },
                                 'helm': {
                                     'type': 'object',
                                     'properties': {
@@ -1279,6 +1291,9 @@ class GitLabracadabraProject(GitLabracadabraObject, BoardsMixin, GroupsMixin, Im
                             'type': 'object',
                             'description': 'PyPI source',
                             'properties': {
+                                'enabled': {
+                                    'type': 'boolean',
+                                },
                                 'pypi': {
                                     'type': 'object',
                                     'properties': {
