@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2021 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -20,12 +20,13 @@ from __future__ import annotations
 from logging import getLogger
 from typing import Optional
 
-from requests import RequestException, Session, codes
+from requests import RequestException, codes
 
 from gitlabracadabra.auth_info import AuthInfo
 from gitlabracadabra.packages.package_file import PackageFile
 from gitlabracadabra.packages.source import Source
 from gitlabracadabra.packages.stream import Stream
+from gitlabracadabra.session import Session
 
 
 logger = getLogger(__name__)
@@ -39,7 +40,7 @@ class Destination(object):
         *,
         log_prefix: str = '',
     ) -> None:
-        """Initialize Destionation repository.
+        """Initialize Destination repository.
 
         Args:
             log_prefix: Log prefix.
@@ -276,7 +277,7 @@ class Destination(object):
             upload_response = self._session.request(
                 upload_method,
                 upload_url,
-                data=Stream(download_response),  # type: ignore
+                data=Stream(download_response),
                 headers=auth_info.headers,
                 auth=auth_info.auth,
             )
