@@ -18,6 +18,7 @@
 from __future__ import annotations
 
 from logging import getLogger
+from os import getenv
 from typing import Optional
 
 from github import Github as PyGithub
@@ -71,7 +72,9 @@ class Github(Source):
         self._zipball = zipball or False
         self._assets = assets or []
 
-        self._repo = PyGithub().get_repo(self._full_name, lazy=True)
+        self._repo = PyGithub(
+            login_or_token=getenv('GITHUB_TOKEN'),
+        ).get_repo(self._full_name, lazy=True)
         self._all_releases: Optional[dict[str, GitRelease]] = None
         self._matching_releases: Optional[dict[str, GitRelease]] = None
 
