@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 Mathieu Parent <math.parent@gmail.com>
+# Copyright (C) 2019-2022 Mathieu Parent <math.parent@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -16,20 +16,23 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from unittest import skipIf
+
+from gitlab import __version__ as gitlab_version
+
+from packaging.version import parse as version_parse
+
 from gitlabracadabra.objects.application_settings import GitLabracadabraApplicationSettings
 from gitlabracadabra.tests import my_vcr
 from gitlabracadabra.tests.case import TestCaseWithManager
 
 
 class TestApplicationSettings(TestCaseWithManager):
+    @skipIf(version_parse(gitlab_version) < version_parse('3.7.0'), 'python-gitlab without proper array support')
     @my_vcr.use_cassette
     def test_settings(self, cass):
         # On the GitLab rails console, before recording:
-        # defaults = ApplicationSetting.defaults
-        # defaults.delete(:throttle_protected_paths_in_seconds)
-        # defaults.delete(:throttle_protected_paths_per_period)
-        # defaults.delete(:elasticsearch_max_bulk_size_bytes)
-        # ApplicationSetting.find_or_create_without_cache.update!(defaults)
+        # ApplicationSetting.first.delete
         obj = GitLabracadabraApplicationSettings('memory', 'application_settings', {
             # 'abuse_notification_email': 'some string',
             # 'admin_mode': True,
@@ -131,7 +134,7 @@ class TestApplicationSettings(TestCaseWithManager):
             # 'enforce_namespace_storage_limit': True,
             # 'enforce_pat_expiration': False,
             # 'enforce_ssh_key_expiration': 'some string',
-            'enforce_terms': True,
+            # 'enforce_terms': True,
             # 'external_auth_client_cert': 'some string',  # FIXME is not a valid X509 certificate.
             # 'external_auth_client_key': 'some string',  # FIXME could not read private key, is the passphrase correct?
             'external_auth_client_key_pass': 'some string',
